@@ -83,10 +83,15 @@ def get_schema_values_recursive(schema, value_name, recursion=False):
     return dict() if not recursion and example is None else example
 
 
-def validate_settings(settings, settings_type, platform_name=None):
+def validate_settings(settings, settings_type, token_info=None, platform_name=None):
     import jsonschema
     from stratus_api.core.exceptions import ApiError
     from stratus_api.integrations import get_integration_function, get_schema_values_recursive
+
+    if 'rate' in settings.keys():
+        if not token_info or 'post:rate' not in token_info['scope']:
+            raise ApiError('Only internal users can create destinations with a rate')
+
     template_mapping = dict(
         destination=get_integration_function(function_name='get_destination_template'),
         segment=get_integration_function(function_name='get_segment_template'),
@@ -102,9 +107,10 @@ def validate_settings(settings, settings_type, platform_name=None):
     return enriched_settings
 
 
-def create_entity(entity_type, name, platform_name, settings, **kwargs):
+def create_entity(entity_type, name, platform_name, settings, token_info, **kwargs):
     validate_platform_name(platform_name=platform_name)
     enriched_settings = validate_settings(platform_name=platform_name, settings=settings,
+                                          token_info=token_info,
                                           settings_type=entity_type)
     create_external_segment = get_integration_function(function_name='create_{entity}'.format(entity=entity_type))
     external_id, external_attributes = create_external_segment(
